@@ -13,6 +13,11 @@ from ...helper import construct_site_based_regex
 REGEX = construct_site_based_regex(ZORO, extra_regex=r"(/watch)?/[\w-]+-(\d+)")
 TITLES_REGEX = regex.compile(r'<h2 class="film-name dynamic-name" .+?>(.+?)</h2>')
 
+XHR_HEADERS = {
+    "X-Requested-With": "XMLHttpRequest",
+    "Referer": ZORO,
+}
+
 
 def int_or(string, *, default=0):
     if string.isdigit():
@@ -26,14 +31,17 @@ SERVER_IDS = {4: "rapidvideo", 1: "rapidvideo", 5: "streamsb", 3: "streamtape"}
 def extract_episode(session, data_id, title):
     for server in htmlparser.fromstring(
         session.get(
-            "https://zoro.to/ajax/v2/episode/servers", params={"episodeId": data_id}
+            ZORO + "ajax/v2/episode/servers",
+            params={"episodeId": data_id},
+            headers=XHR_HEADERS,
         )
         .json()
         .get("html")
     ).cssselect("div.server-item"):
         source_data = session.get(
-            "https://zoro.to/ajax/v2/episode/sources",
+            ZORO + "ajax/v2/episode/sources",
             params={"id": server.get("data-id")},
+            headers=XHR_HEADERS,
         ).json()
         if source_data.get("type") != "iframe":
             yield {
@@ -61,7 +69,9 @@ def fetcher(session, url, check, match):
     slug = match.group(2)
 
     for episode in htmlparser.fromstring(
-        session.get(ZORO + "/ajax/v2/episode/list/{}".format(slug)).json().get("html")
+        session.get(ZORO + "ajax/v2/episode/list/{}".format(slug), headers=XHR_HEADERS)
+        .json()
+        .get("html")
     ).cssselect("a[title][data-number][data-id]"):
         episode_number = int_or(episode.get("data-number", "") or "")
         if check(episode_number):
